/*	$Id: ort-lang-javascript.h,v 1.5 2021/05/14 08:21:43 kristaps Exp $ */
/*
 * Copyright (c) 2020 Kristaps Dzonsons <kristaps@bsd.lv>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef ORT_LANG_JAVASCRIPT_H
#define ORT_LANG_JAVASCRIPT_H

#define	ORT_LANG_JS_EXPORT	0x01
#define ORT_LANG_JS_DEFAULT_NS	"ort"

struct	ort_lang_js {
	const char	*ext_privMethods;
	const char	*ns;
	unsigned int	 flags;
};

int	ort_lang_javascript(const struct config *, 
		const struct ort_lang_js *, FILE *);

#endif /* !ORT_LANG_JAVASCRIPT_H */
